@@ -102,9 +102,12 @@ class FeatureUtil(object):
             cross_features_index = [[[i, int(y.split(':')[0])] for y in re.split(', |,', sample.split('@')[feature_id['cross_feature']])] for i, sample in enumerate(data)]
             cross_features_index, cross_features_val = self.cross_features_batch(cross_features_index, cross_features_val)
             # 序列特征，padding
-            sequence_id = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_id]
-            sequence_time = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_time]
-            sequence_time_gaps = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_time_gaps]
+            sequence_id = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post', dtype='int64') for x in sequence_id]
+            sequence_time = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post', dtype='int64') for x in sequence_time]
+            sequence_time_gaps = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post', dtype='int64') for x in sequence_time_gaps]
+            # sequence_id = sequence.pad_sequences(sequence_id, maxlen=self.maxlen, padding='post')
+            # sequence_time = sequence.pad_sequences(sequence_time, maxlen=self.maxlen, padding='post')
+            # sequence_time_gaps = sequence.pad_sequences(sequence_time_gaps, maxlen=self.maxlen, padding='post')
             # mask、label，处理成 multi-hot
             mask, label = self.mask_label_multi_hot(mask, label)
 
