@@ -13,15 +13,19 @@ class controllerObs(object):
         self.config = config
         self.FeatureUtil = FeatureUtil(config)
         self.model = model
-        saver = tf.train.Saver()
-        sess = tf.keras.backend.get_session()
-        saver.restore(sess, modelfile)
+        # saver = tf.train.Saver()
+        # sess = tf.keras.backend.get_session()
+        # saver.restore(sess, modelfile)
 
         self.item_emb1 = self.model.get_layer('embedding_1').get_weights()[0]
         self.item_emb2 = self.model.get_layer('embedding_2').get_weights()[0]
         self.item_embs = [self.item_emb1, self.item_emb2]
 
-        self.mid_layer_model = tf.keras.backend.function(self.model.input, self.model.get_layer('tf_op_layer_mean/mean').output)
+        # self.mid_layer_model = tf.keras.backend.function(self.model.input, self.model.get_layer('tf_op_layer_mean/mean').output)
+        self.mid_layer_model = tf.keras.backend.function(self.model.input, self.model.get_layer('concatenate_1').output)
+        # self.mid_layer_model = tf.keras.backend.function(self.model.input, self.model.get_layer('lstm').output)
+
+
 
         self.sess = sess
         self.src = src
